# Change Log

# [v0.2.2](https://github.com/topic2k/pygcgen/tree/v0.2.2) (2017-04-21)
[Full Changelog](https://github.com/topic2k/pygcgen/compare/v0.2.1...v0.2.2)

**Fixed bugs:**

- Skip non-merged closed issues? [\#18](https://github.com/topic2k/pygcgen/pull/18) ([alexanderad](https://github.com/alexanderad))

**Closed issues:**

- Links in unreleased section don't work [\#16](https://github.com/topic2k/pygcgen/issues/16)

**Merged pull requests:**

- changes for using pygcgen with python 2.7 [\#19](https://github.com/topic2k/pygcgen/pull/19) ([topic2k](https://github.com/topic2k))

# [v0.2.1](https://github.com/topic2k/pygcgen/tree/v0.2.1) (2016-10-07)
[Full Changelog](https://github.com/topic2k/pygcgen/compare/v0.2.0...v0.2.1)

**Implemented enhancements:**

- add quiet option [\#14](https://github.com/topic2k/pygcgen/pull/14) ([topic2k](https://github.com/topic2k))

**Closed issues:**

- Issues missing if no section given [\#12](https://github.com/topic2k/pygcgen/issues/12)

**Merged pull requests:**

- Show issues in changelog when no section\(s\) were given. [\#13](https://github.com/topic2k/pygcgen/pull/13) ([topic2k](https://github.com/topic2k))

# [v0.2.0](https://github.com/topic2k/pygcgen/tree/v0.2.0) (2016-10-07)
[Full Changelog](https://github.com/topic2k/pygcgen/compare/v0.1.2...v0.2.0)

## <u>**Usage changes:</u>**

- Add user definable sections [\#7](https://github.com/topic2k/pygcgen/issues/7)

**Implemented enhancements:**

- new option: tag-separator [\#11](https://github.com/topic2k/pygcgen/pull/11) ([topic2k](https://github.com/topic2k))

# [v0.1.2](https://github.com/topic2k/pygcgen/tree/v0.1.2) (2016-10-02)
[Full Changelog](https://github.com/topic2k/pygcgen/compare/v0.1.1...v0.1.2)

**Closed issues:**

- Show example file! [\#2](https://github.com/topic2k/pygcgen/issues/2)
- Publish to PyPI [\#1](https://github.com/topic2k/pygcgen/issues/1)

**Merged pull requests:**

- Python 2+3 compatibility [\#6](https://github.com/topic2k/pygcgen/pull/6) ([topic2k](https://github.com/topic2k))

# [v0.1.1](https://github.com/topic2k/pygcgen/tree/v0.1.1) (2016-09-11)
[Full Changelog](https://github.com/topic2k/pygcgen/compare/v0.1.0...v0.1.1)

**Merged pull requests:**

- Add option to keep output file if it exists [\#5](https://github.com/topic2k/pygcgen/pull/5) ([topic2k](https://github.com/topic2k))
- Prepare for releasing on PyPi. [\#4](https://github.com/topic2k/pygcgen/pull/4) ([topic2k](https://github.com/topic2k))

# [v0.1.0](https://github.com/topic2k/pygcgen/tree/v0.1.0) (2016-09-11)
**Implemented enhancements:**

- Add option to use GitHub tags instead of markdown links [\#3](https://github.com/topic2k/pygcgen/pull/3) ([topic2k](https://github.com/topic2k))

